/*
  This file is part of ccbuild.

  ccbuild is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  ccbuild is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "source.ih"
std::string Source::basenameWithoutExtension() const {
    std::string basename = FileSystem::baseName(d_filename);
    std::string::size_type i = basename.rfind('.');
    if(i == string::npos) {
        throw Problem(Problem::Missing, "Can not find extension in a file which was requested without extension. Basename: " + basename);
    }
    return basename.substr(0, i);
}
